Overview
========

A system for automated device discovery and commmunication,
using UDP (for discovery) and MQTT (via mosquito and
Paho-mqtt) for communication.

It is a work in progress.

Installation
============

Development
===========

PyCharm
-------

